<?php

namespace Gateway;

use Config\Connection;
use Config\ConnectClass;
use PDO;
use PDOException;

class GatewayListResponseOfCandidate
{
    private Connection $connection;

    public function __construct()
    {
        try{
            $this->connection = (new ConnectClass)->connect();
        }catch(PDOException $e){
            throw new PDOException($e->getMessage(), $e->getCode(), $e);
        }
    }

    public function getDetailsListResponsesOfCandidate(int $idListResponse): array
    {
        $gatewayResponse = new GatewayResponse();
        $gatewayKeyword = new GatewayKeyword();
        $tabKeywords = [];

        $query = "SELECT * FROM ListResponsesOfCandidate WHERE id = :id";
        $this->connection->executeQuery($query, array(
            ':id' => array($idListResponse, PDO::PARAM_INT)
        ));

        $questionList = $this->connection->getResults()[0];

        $responses = $gatewayResponse->getResponsesByIdListCandidate($questionList['id']);

        foreach ($responses as $row) {
            $tabKeywords[] = $gatewayKeyword->getKeywordsContentByReference($row['id']);
        }

        return array($questionList, $responses, $tabKeywords);
    }

    public function getAllListResponsesOfCandidate(): array
    {
        $query = "SELECT * FROM ListResponsesOfCandidate";
        $this->connection->executeQuery($query);

        return $this->connection->getResults();
    }

    public function deleteListResponseOfCandidate(int $id): void
    {
        $gatewayResponse = new GatewayResponse();

        foreach ( $gatewayResponse->getResponsesIdByIdListCandidate($id) as $response){
            $gatewayResponse->deleteResponseById($response);
        }

        $query = "DELETE FROM ListResponsesOfCandidate WHERE id = :id";
        $this->connection->executeQuery($query, array(
            'id' => array($id, PDO::PARAM_STR)
        ));
    }

    public function insertListResponsesOfCandidate(array $answer, string $titleForm,int $idQuestion): void
    {
        $gatewayResponse = new GatewayResponse();
        $gatewayQuestion = new GatewayQuestion();

        $query = "INSERT INTO ListResponsesOfCandidate(date, titleForm) VALUES(:date, :titleForm)";
        $this->connection->executeQuery($query, array(
            ':date' => array(date('Y-m-d H:i:s'), PDO::PARAM_STR),
            ':titleForm' => array($titleForm, PDO::PARAM_STR)           //parameters[3] = titleForm
        ));

        $idListQuestion = $this->connection->lastInsertId();

        for($i = 0; $i < count($answer); $i++)                   //parameters[1] = answer
        {
            $idResponse = $gatewayResponse->insertResponse($gatewayQuestion->getQuestionContentById($idQuestion), "",array()); //$parameters[1][$i], $parameters[2][$i]));     //parameters[1] = answer, parameters[2] = category, parameters[3] = id

            $query = "INSERT INTO Submit (responsesCandidate, response) VALUES(:responsesCandidate, :response)";
            $this->connection->executeQuery($query, array(
                ':responsesCandidate' => array($idListQuestion, PDO::PARAM_STR),
                'response' => array($idResponse, PDO::PARAM_STR)
            ));
        }
    }
}
